@@ -1,7 +1,7 @@
 # HotBot.pm
 # by Wm. L. Scheding and Martin Thurn
 # Copyright (C) 1996-1998 by USC/ISI
-# $Id: HotBot.pm,v 1.43 1999/11/12 15:32:39 mthurn Exp $
+# $Id: HotBot.pm,v 1.46 1999/12/22 20:44:29 mthurn Exp $
 
 =head1 NAME
 
@@ -296,6 +296,18 @@ MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 If it''s not listed here, then it wasn''t a meaningful nor released revision.
 
+=head2 2.10, 1999-12-22
+
+handle new result format
+
+=head2 2.09, 1999-12-15
+
+handle new result count format
+
+=head2 2.08, 1999-12-10
+
+handle new output format
+
 =head2 2.07, 1999-11-12
 
 BUGFIX for domain-limited URL parsing (thanks to Leon Brocard)
@@ -394,13 +406,13 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 @ISA = qw(WWW::Search Exporter);
-$VERSION = '2.07';
+$VERSION = '2.10';
 
 $MAINTAINER = 'Martin Thurn <MartinThurn@iname.com>';
 $TEST_CASES = <<"ENDTESTCASES";
 &test('HotBot', '$MAINTAINER', 'zero', \$bogus_query, \$TEST_EXACTLY);
 &test('HotBot', '$MAINTAINER', 'one', 'LSAM replication', \$TEST_RANGE, 2,80);
-&test('HotBot', '$MAINTAINER', 'two', 'Calri'.'ssian', \$TEST_GREATER_THAN, 101);
+&test('HotBot', '$MAINTAINER', 'two', 'Bo'.'ss Na'.'ss', \$TEST_GREATER_THAN, 101);
 ENDTESTCASES
 
 use Carp ();
@@ -518,10 +530,11 @@ sub native_retrieve_some
       } # We're in TITLE mode, and line has title
 
     elsif ($state eq $HEADER && 
-           m!(?:\s|\&nbsp\;)([\d,]+)(?:\s|\&nbsp\;)+Matches.!i)
+           m!Returned:(?:$WHITESPACE|fewer|less|more|than)+([\d,]+)$WHITESPACE+(Matches.)?!i)
       {
       # Actual line of input is:
       # <b>Returned:&nbsp;69&nbsp;Matches&nbsp;
+      # <b>Returned:&nbsp;&nbsp;more&nbsp;than&nbsp;500,000&nbsp;&nbsp;
       my $iCount = $1;
       $iCount =~ s/\D//g;
       print STDERR "count line ($iCount) " if 2 <= $self->{'_debug'};
@@ -529,10 +542,10 @@ sub native_retrieve_some
       $state = $NEXT;
       } # we're in HEADER mode, and line has number of results
 
-    elsif ($state eq $NEXT && m|href="[^"?]+\?([^"]*act\.next=next[^"]+)|)
+    elsif ($state eq $NEXT && m|href="[^"?]+\?([^\"]*?)">next</a>|)
       {
       # Actual line of input:
-      #        <b>1&nbsp;-&nbsp;100&nbsp;</b><a href="/text/results.asp?act.next=next&MT=IG%2D88&SM=SC&DC=100&BT=T">next</a><font color="#FF0000" face="courier" size=1>&nbsp;<b>&gt;&gt;</b></font>
+      #  <b>1&nbsp;-&nbsp;100&nbsp;</b> <a href="/text/default.asp?MT=Calrissian&SM=SC&II=100&RPN=2&DC=100&BT=T">next</a><font color="#FF0000" face="courier" size=1>&nbsp;<b>&gt;&gt;</b></font><br>
       print STDERR " found next button" if 2 <= $self->{'_debug'};
       # There is a "next" button on this page, therefore there are
       # indeed more results for us to go after next time.
@@ -541,7 +554,10 @@ sub native_retrieve_some
       $self->{'_next_to_retrieve'} += $self->{'_hits_per_page'};
       $state = $HITS;
       } # found "next" link in NEXT mode
-    elsif ($state eq $NEXT && m|^\074p\076\s\074b\076(\d+)\.| )
+    elsif ($state eq $NEXT && (
+                               m|^(?:\074p\076\s)?\074b\076(\d+)\.|   ||
+                               m/<!-- BRES --> /                 
+                              ))
       {
       print STDERR " no next button; " if 2 <= $self->{'_debug'};
       # There was no "next" button on this page; no more pages to get!
@@ -551,7 +567,7 @@ sub native_retrieve_some
       # pattern matches this line (again)!
       }
 
-    if ($state eq $HITS && m|^\074p\076\s\074b\076(\d+)\.| )
+    if ($state eq $HITS && m|^(?:\074p\076\s)?\074b\076(\d+)\.| )
       {
       print STDERR "multihit line" if 2 <= $self->{'_debug'};
       # Actual line of input as of 1999-10-18:
